const assert = require('assert');
/*eslint-disable*/
const { jsonToEnums, jsonToKeyMap, jsonToArray, mask, pad } = require('../transform');
describe('# Transform', function () {
  const json = {
    key1: 0,
    key2: 1,
    key3: 2
  };
  it('## jsonToEnums', function () {
    const arr = jsonToEnums(json);
    assert(Array.isArray(arr), 'returns should be an array');
    const expect = [0, 1, 2];
    assert(expect.length === arr.length, 'returns length should equals expect length');
    assert(expect.every(item => arr.includes(item)), 'returns items should includes expect items');
  });
  it('## jsonToKeyMap', function () {
    const keyMap = jsonToKeyMap(json);
    assert(Array.isArray(keyMap), 'returns should be an array');
    const expect = ['key1', 'key2', 'key3'];
    assert(expect.length === keyMap.length, 'returns length should equals expect length');
    assert(expect.every(item => keyMap.includes(item)), 'returns items should includes expect items');
  });
  it('## jsonToArray', function () {
    const arr = jsonToArray(json);
    assert(Array.isArray(arr), 'returns should be an array');
    const expect = [{
      key: 'key1', value: 0
    }, {
      key: 'key2', value: 1
    }, {
      key: 'key3', value: 2
    }];
    assert(expect.length === arr.length, 'returns length should equals expect length');
    assert(expect.every((item, index) => (item.key === arr[index].key && item.value === arr[index].value)), 'returns items should equal expect items');
  });
  it('## mask', function () {
    const str = '18888888888';
    const maskedString = mask(str, 3, 4, '*');
    assert(maskedString === '188****8888');
  });
  it('## pad', function () {
    assert(pad(12, 3) === '012');
    assert(pad(0, 4) === '0000');
    assert(pad(123, 2) === '23');
  });
});

