/**
 * 通过角度计算弧度值
 * @param  {number} d 角度值
 * @returns {number} 计算得到的弧度值
 */
module.exports.getRad = d => d * Math.PI / 180.0;

/**
 * 计算两点的地理距离
 * @param {Array} location1 经纬度
 * @param {Array} location2 经纬度
 * @returns {number} 计算得到的距离值
 */
module.exports.calcDistance = (location1, location2) => {
  const radLat1 = module.exports.getRad(location1[1]);
  const radLat2 = module.exports.getRad(location2[1]);
  const a = radLat1 - radLat2;
  const b = module.exports.getRad(location1[0]) - module.exports.getRad(location2[0]);
  let s = 2 * Math.asin(Math.sqrt(Math.pow(Math.sin(a / 2), 2) + (Math.cos(radLat1) * Math.cos(radLat2) * Math.pow(Math.sin(b / 2), 2))));
  s *= 6378137;
  s = Math.round(s * 10000) / 10000;
  return s;
};
