const crypto = require('crypto');
const nodeRSA = require('node-rsa');
const fs = require('fs');

module.exports.md5 = (v, encode = 'hex') => crypto.createHash('md5').update(v).digest(encode);

module.exports.sha1 = (v, encode = 'hex') => crypto.createHash('sha1').update(v).digest(encode);

module.exports.hmacSha1 = (v, key, encode = 'hex') => crypto.createHmac('sha1', key).update(v).digest(encode);

module.exports.hmacSha256 = (v, key, encode = 'hex') => crypto.createHmac('sha256', key).update(v).digest(encode);

module.exports.rsa = (keyPath, options = {
  signingScheme: 'sha1',
  encryptionScheme: 'pkcs1'
}) => {
  const key = nodeRSA(fs.readFileSync(keyPath), options);
  return {
    encrypt: key.encrypt.bind(key),
    decrypt: key.decrypt.bind(key),
    sign: key.sign.bind(key),
    verify: key.verify.bind(key)
  };
};

module.exports.aes256 = (key, iv, charset = 'utf-8', encode = 'base64') => {
  const cipher = crypto.createCipheriv('aes256', key, iv);
  const decipher = crypto.createDecipheriv('aes256', key, iv);
  return {
    encode: input => cipher.update(input, charset, encode) + cipher.final(encode),
    decode: input => decipher.update(input, encode, charset) + decipher.final(charset)
  };
};